==> nocc-1.9.5.txz: usr/local/www/nocc/lang/lt.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: lt.php 2602 2014-03-31 22:00:26Z siebrand $
 */
/** Lithuanian (lietuvių)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cyklopas
 * @author Eitvys200
 */

$err_user_empty = 'Prisijungimo laukas yra tuščias';
$err_passwd_empty = 'Slaptažodžio laukas yra tuščias';
$alt_delete = 'Ištrinti pasirinktus laiškus';
$alt_delete_one = 'Trinti žinutę';
$alt_new_msg = 'Nauja žinutė';
$alt_reply = 'Atsakyti autoriui';
$alt_reply_all = 'Atsakyti visiems';
$alt_forward = 'Pirmyn';
$alt_next = 'Kitas';
$alt_prev = 'Ankstesnis';
$title_next_page = 'Kitas puslapis';
$title_prev_page = 'Ankstesnis puslapis';
$title_next_msg = 'Kita žinutė';
$title_prev_msg = 'Ankstesnė žinutė';
$html_theme_label = 'Tema:';
$html_welcome = 'Sveiki atvykę į %1$s';
$html_login = 'Prisijungti';
$html_user_label = 'Vartotojas:';
$html_passwd_label = 'Slaptažodis:';
$html_submit = 'Siųsti';
$html_help = 'Pagalba';
$html_server_label = 'Serveris:';
$html_wrong = 'Prisijungimo vardas arba slaptažodis yra neteisingas';
$html_retry = 'Bandykite dar kartą';
$html_remember = 'Prisiminti nustatymus';
$html_lang_label = 'Kalba:';
$html_msgperpage_label = 'Žinučių skaičius puslapyje:';
$html_preferences = 'Nustatymai';
$html_full_name_label = 'Pilnas vardas:';
$html_email_address_label = 'El. pašto adresas:';
$html_hide_addresses = 'Slėpti adresus';
$html_reply_to = 'Atsakyti';
$html_reply_to_label = 'Atsakyti į:';
$html_use_signature = 'Naudoti parašą';
$html_signature = 'Parašas';
$html_signature_label = 'Parašas:';
$html_prefs_updated = 'Nustatymai atnaujinti';
$html_manage_folders_link = 'Tvarkyti IMAP aplankus';
$html_manage_filters_link = 'Tvarkyti el. pašto filtrus';
$html_use_graphical_smilies = 'Naudoti grafines šypsenėles';
$html_send_html_mail = 'Siųsti el. laišką HTML formatu';
$html_folders = 'Aplankai';
$html_folders_create_failed = 'Aplanko sukurti neįmanoma!';
$html_folders_rename_failed = 'Aplankas negali būti pervadintas!';
$html_folders_updated = 'Aplankai atnaujinti';
$html_folder_subscribe = 'Prenumeruoti';
$html_folder_rename = 'Pervadinti';
$html_folder_create = 'Sukurti naują aplanką, pavadinimu';
$html_folder_delete = 'Ištrinti';
$html_folder_to = 'į';
$html_filter_remove = 'Ištrinti';
$html_filter_body = 'Pranešimo tekstas';
$html_filter_subject = 'Laiško temą';
$html_filter_name = 'Filtro pavadinimas';
$html_filter_action = 'Filtro veiksmai';
$html_filter_moveto = 'Perkelti į';
$html_select_one = '- Pasirinkite vieną -';
$html_and = 'Ir';
$html_new_msg_in = 'Nauji pranešimai';
$html_or = 'arba';
$html_move = 'Perkelti';
$html_copy = 'Kopijuoti';
$html_gotopage = 'Eiti į puslapį';
$html_gotofolder = 'Eiti į aplanką';
$html_other_folders = 'Aplankų sąrašas';
$html_page = 'Puslapis';
$html_inbox = 'Gautieji';
$html_new_msg = 'Rašyti';
$html_reply = 'Atsakyti';
$html_reply_short = 'Re:';
$html_reply_all = 'Atsakyti visiems';
$html_delete = 'Ištrinti';
$html_new = 'Nauja';
$html_mark = 'Ištrinti';
$html_att_label = 'Priedas:';
$html_atts_label = 'Priedai:';
$html_unknown = '[Nežinomas]';
$html_part_x = 'Dalis %s';
$html_attach = 'Pridėti';
$html_attach_forget = 'Jūs turite pridėti failą prieš siųsdami savo pranešimą!';
$html_attach_delete = 'Pašalinti pažymėta';
$html_attach_none = 'Jūs turite pasirinkti failą prisegimui!';
$html_sort_by = 'Rūšiuoti pagal';
$html_sort = 'Rūšiuoti';
$html_from = 'Nuo';
$html_from_label = 'Nuo:';
$html_subject = 'Tema';
$html_subject_label = 'Tema:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Išsiųsti:';
$html_wrote = 'rašė';
$html_size = 'Dydis';
$html_totalsize = 'Visas dydis';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'baitų';
$html_filename = 'Failo pavadinimas';
$html_to = 'Kam';
$html_to_label = 'Kam:';
$html_nosubject = 'Nėra temos';
$html_send = 'Siųsti';
$html_cancel = 'Atšaukti';
$html_no_mail = 'Nėra pranešimų';
$html_logout = 'Atsijungti';
$html_msg = 'Žinutė';
$html_msgs = 'Žinutės';
$html_lowest = 'Mažiausias';
$html_low = 'Žemas';
$html_normal = 'Normalus';
$html_high = 'Aukštas';
$html_highest = 'Aukščiausias';
$html_spam = 'Šlamštas';
$html_select = 'Pasirinkti';
$html_select_contacts = 'Pasirinkite kontaktus';
$html_loading_image = 'Kraunasi vaizdas';
$html_send_confirmed = 'Jūsų el. paštas buvo priimtas dėl pristatymo';
$html_mark_as = 'Žymėti kaip';
$html_read = 'skaitytas';
$html_unread = 'neskaitytas';
$html_add = 'Pridėti';
$html_contacts = '%1$s Kontaktai';
$html_back = 'Atgal';
$html_contact_add = 'Pridėti naują adresatą';
$html_contact_first = 'Vardas';
$html_contact_last = 'Pavardė';
$html_contact_nick = 'Nikas';
$html_contact_mail = 'E-paštas';
$html_contact_list = 'Kontaktų sąrašas %1$s';
$html_contact_count = '%1$d Kontaktai';
$html_contact_err1 = 'Maksimalus kontaktų skaičius yra " %1$d "';
$html_contact_err2 = 'Jūs negalite pridėti naują kontaktą';
$html_contact_err3 = 'Jūs neturite prieigos teisių prie kontaktų sąrašo';
$html_contact_none = 'Nerasta jokių kontaktų.';
$html_del_msg = 'Pašalinti pažymėtus laiškus?';
$html_down_mail = 'Parsisiųsti';
$original_msg = '- Originali Žinutė -';
$html_images_display = 'Rodyti nuotraukas';
$lang_could_not_connect = 'Nepavyko prisijungti prie serverio';
$lang_invalid_msg_num = 'Blogas žinutės numeris';
$html_invalid_email_address = 'Neteisingas elektroninio pašto adresas';
$html_invalid_msg_per_page = 'Neleistinas skaičius pranešimų puslapyje';
$html_search = 'Paieška';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/lt.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: lt.php 2662 2016-03-09 12:43:49Z siebrand $
 */
/** Lithuanian (lietuvių)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cyklopas
 * @author Eitvys200
 * @author Zygimantus
 */

$err_user_empty = 'Prisijungimo laukas yra tuščias';
$err_passwd_empty = 'Slaptažodžio laukas yra tuščias';
$alt_delete = 'Ištrinti pasirinktas žinutes';
$alt_delete_one = 'Trinti žinutę';
$alt_new_msg = 'Nauja žinutė';
$alt_reply = 'Atsakyti autoriui';
$alt_reply_all = 'Atsakyti visiems';
$alt_forward = 'Pirmyn';
$alt_next = 'Kitas';
$alt_prev = 'Ankstesnis';
$title_next_page = 'Kitas puslapis';
$title_prev_page = 'Ankstesnis puslapis';
$title_next_msg = 'Kita žinutė';
$title_prev_msg = 'Ankstesnė žinutė';
$html_theme_label = 'Tema:';
$html_welcome = 'Sveiki atvykę į %1$s';
$html_login = 'Prisijungti';
$html_user_label = 'Vartotojas:';
$html_passwd_label = 'Slaptažodis:';
$html_submit = 'Siųsti';
$html_help = 'Pagalba';
$html_server_label = 'Serveris:';
$html_wrong = 'Prisijungimo vardas arba slaptažodis yra neteisingas';
$html_retry = 'Bandykite dar kartą';
$html_remember = 'Prisiminti nustatymus';
$html_lang_label = 'Kalba:';
$html_msgperpage_label = 'Žinučių skaičius puslapyje:';
$html_preferences = 'Nustatymai';
$html_full_name_label = 'Pilnas vardas:';
$html_email_address_label = 'El. pašto adresas:';
$html_hide_addresses = 'Slėpti adresus';
$html_reply_to = 'Atsakyti';
$html_reply_to_label = 'Atsakyti į:';
$html_use_signature = 'Naudoti parašą';
$html_signature = 'Parašas';
$html_signature_label = 'Parašas:';
$html_prefs_updated = 'Nustatymai atnaujinti';
$html_manage_folders_link = 'Tvarkyti IMAP aplankus';
$html_manage_filters_link = 'Tvarkyti el. pašto filtrus';
$html_use_graphical_smilies = 'Naudoti grafines šypsenėles';
$html_colored_quotes = 'Spalvotos citatos';
$html_send_html_mail = 'Siųsti el. laišką HTML formatu';
$html_folders = 'Aplankai';
$html_folders_create_failed = 'Aplanko sukurti neįmanoma!';
$html_folders_rename_failed = 'Aplankas negali būti pervadintas!';
$html_folders_updated = 'Aplankai atnaujinti';
$html_folder_subscribe = 'Prenumeruoti';
$html_folder_rename = 'Pervadinti';
$html_folder_create = 'Sukurti naują aplanką, pavadinimu';
$html_folder_delete = 'Ištrinti';
$html_folder_to = 'į';
$html_filter_remove = 'Ištrinti';
$html_filter_body = 'Pranešimo tekstas';
$html_filter_subject = 'Laiško tema';
$html_filter_contains = 'turi';
$html_filter_name = 'Filtro pavadinimas';
$html_filter_action = 'Filtro veiksmas';
$html_filter_moveto = 'Perkelti į';
$html_select_one = '- Pasirinkite vieną -';
$html_and = 'Ir';
$html_new_msg_in = 'Nauji pranešimai';
$html_or = 'arba';
$html_move = 'Perkelti';
$html_copy = 'Kopijuoti';
$html_gotopage = 'Eiti į puslapį';
$html_gotofolder = 'Eiti į aplanką';
$html_other_folders = 'Aplankų sąrašas';
$html_page = 'Puslapis';
$html_view_header = 'Peržiūrėti antraštę';
$html_remove_header = 'Paslėpti antraštę';
$html_inbox = 'Gautieji';
$html_new_msg = 'Rašyti';
$html_reply = 'Atsakyti';
$html_reply_short = 'Re:';
$html_reply_all = 'Atsakyti visiems';
$html_delete = 'Ištrinti';
$html_new = 'Nauja';
$html_mark = 'Ištrinti';
$html_att_label = 'Priedas:';
$html_atts_label = 'Priedai:';
$html_unknown = '[Nežinomas]';
$html_part_x = 'Dalis %s';
$html_attach = 'Pridėti';
$html_attach_forget = 'Jūs turite pridėti failą prieš siųsdami savo pranešimą!';
$html_attach_delete = 'Pašalinti pasirinktą(-us)';
$html_attach_none = 'Jūs turite pasirinkti failą prisegimui!';
$html_sort_by = 'Rūšiuoti pagal';
$html_sort = 'Rūšiuoti';
$html_from = 'Nuo';
$html_from_label = 'Nuo:';
$html_subject = 'Tema';
$html_subject_label = 'Tema:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Išsiųsti:';
$html_wrote = 'rašė';
$html_size = 'Dydis';
$html_totalsize = 'Visas dydis';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'baitų';
$html_filename = 'Failo pavadinimas';
$html_to = 'Kam';
$html_to_label = 'Kam:';
$html_nosubject = 'Nėra temos';
$html_send = 'Siųsti';
$html_cancel = 'Atšaukti';
$html_no_mail = 'Nėra pranešimų';
$html_logout = 'Atsijungti';
$html_msg = 'Žinutė';
$html_msgs = 'Žinutės';
$html_priority = 'Prioritetas';
$html_priority_label = 'Prioritetas:';
$html_lowest = 'Mažiausias';
$html_low = 'Žemas';
$html_normal = 'Normalus';
$html_high = 'Aukštas';
$html_highest = 'Aukščiausias';
$html_flagged = 'Pažymėtas';
$html_spam = 'Šlamštas';
$html_select = 'Pasirinkti';
$html_select_all = 'Žymėti priešingai';
$html_select_contacts = 'Pasirinkite kontaktus';
$html_loading_image = 'Kraunasi vaizdas';
$html_send_confirmed = 'Jūsų el. paštas buvo priimtas dėl pristatymo';
$html_error_occurred = 'Įvyko klaida';
$html_mark_as = 'Žymėti kaip';
$html_read = 'skaitytas';
$html_unread = 'neskaitytas';
$html_add = 'Pridėti';
$html_contacts = '%1$s kontaktai';
$html_modify = 'Pakeisti';
$html_back = 'Atgal';
$html_contact_add = 'Pridėti naują adresatą';
$html_contact_mod = 'Pakeisti kontaktą';
$html_contact_first = 'Vardas';
$html_contact_last = 'Pavardė';
$html_contact_nick = 'Slapyvardis';
$html_contact_mail = 'El. paštas';
$html_contact_list = 'Kontaktų sąrašas %1$s';
$html_contact_count = '%1$d Kontaktai';
$html_contact_err1 = 'Maksimalus kontaktų skaičius yra " %1$d "';
$html_contact_err2 = 'Jūs negalite pridėti naują kontaktą';
$html_contact_err3 = 'Jūs neturite prieigos teisių prie kontaktų sąrašo';
$html_contact_none = 'Nerasta jokių kontaktų.';
$html_contact_list_add = 'Pridėti į sąrašą';
$html_contact_listonly = 'Tik sąrašai';
$html_contact_all = 'Rodyti viską';
$html_del_msg = 'Pašalinti pažymėtus laiškus?';
$html_down_mail = 'Parsisiųsti';
$original_msg = '- Originali Žinutė -';
$html_images_display = 'Rodyti nuotraukas';
$lang_could_not_connect = 'Nepavyko prisijungti prie serverio';
$lang_invalid_msg_num = 'Blogas žinutės numeris';
$html_invalid_email_address = 'Neteisingas elektroninio pašto adresas';
$html_invalid_msg_per_page = 'Neleistinas skaičius pranešimų puslapyje';
$html_search = 'Paieška';
$html_new_session = 'Kita sesija';
$html_fd_filename = 'Atsisiųsti %1$s';
$html_collect_option0 = 'Niekada';
$html_collect_option3 = 'Visada';
